==> jc-1.4.0.tar.gz: polyglot/types/ClassResolver.h <==
// public abstract class polyglot.types.ClassResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_ClassResolver_H_
#define _JC_polyglot_types_ClassResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Named$object;

// Typedefs
typedef struct _jc_polyglot_types_ClassResolver$sub_refs	_jc_polyglot_types_ClassResolver$sub_refs;
typedef struct _jc_polyglot_types_ClassResolver$sub_nonrefs	_jc_polyglot_types_ClassResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_ClassResolver$refs	_jc_polyglot_types_ClassResolver$refs;
typedef struct _jc_polyglot_types_ClassResolver$nonrefs	_jc_polyglot_types_ClassResolver$nonrefs;
typedef struct _jc_polyglot_types_ClassResolver$object	_jc_polyglot_types_ClassResolver$object;

typedef const struct _jc_polyglot_types_ClassResolver$vmethods	_jc_polyglot_types_ClassResolver$vmethods;
typedef const struct _jc_polyglot_types_ClassResolver$vtable	_jc_polyglot_types_ClassResolver$vtable;
typedef const struct _jc_polyglot_types_ClassResolver$vtype	_jc_polyglot_types_ClassResolver$vtype;

// Constructors
extern void _jc_polyglot_types_ClassResolver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_ClassResolver$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_ClassResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_ClassResolver$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_ClassResolver$method_info$find$6acc62ea1c707b3c;

// Virtual methods structure
struct _jc_polyglot_types_ClassResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_ClassResolver$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_polyglot_types_ClassResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
};

// Vtype
struct _jc_polyglot_types_ClassResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_ClassResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_ClassResolver$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_ClassResolver$refs {
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_ClassResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_ClassResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
};

// Object instance structure
struct _jc_polyglot_types_ClassResolver$object {
	_jc_polyglot_types_ClassResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_ClassResolver$vtype	*vtype;
	_jc_polyglot_types_ClassResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_ClassResolver$vtype _jc_polyglot_types_ClassResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_ClassResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_ClassResolver$class_object;

#endif	/* _JC_polyglot_types_ClassResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/ClassResolver.h <==
// public abstract class polyglot.types.ClassResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_ClassResolver_H_
#define _JC_polyglot_types_ClassResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Named$object;

// Typedefs
typedef struct _jc_polyglot_types_ClassResolver$sub_refs	_jc_polyglot_types_ClassResolver$sub_refs;
typedef struct _jc_polyglot_types_ClassResolver$sub_nonrefs	_jc_polyglot_types_ClassResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_ClassResolver$refs	_jc_polyglot_types_ClassResolver$refs;
typedef struct _jc_polyglot_types_ClassResolver$nonrefs	_jc_polyglot_types_ClassResolver$nonrefs;
typedef struct _jc_polyglot_types_ClassResolver$object	_jc_polyglot_types_ClassResolver$object;

typedef const struct _jc_polyglot_types_ClassResolver$vmethods	_jc_polyglot_types_ClassResolver$vmethods;
typedef const struct _jc_polyglot_types_ClassResolver$vtable	_jc_polyglot_types_ClassResolver$vtable;
typedef const struct _jc_polyglot_types_ClassResolver$vtype	_jc_polyglot_types_ClassResolver$vtype;

// Constructors
extern void _jc_polyglot_types_ClassResolver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_ClassResolver$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_ClassResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_ClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_ClassResolver$method_info$find$6acc62ea1c707b3c;

// Virtual methods structure
struct _jc_polyglot_types_ClassResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_ClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_ClassResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
};

// Vtype
struct _jc_polyglot_types_ClassResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_ClassResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_ClassResolver$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_ClassResolver$refs {
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_ClassResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_ClassResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
};

// Object instance structure
struct _jc_polyglot_types_ClassResolver$object {
	_jc_polyglot_types_ClassResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_ClassResolver$vtype	*vtype;
	_jc_polyglot_types_ClassResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_ClassResolver$vtype _jc_polyglot_types_ClassResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_ClassResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_ClassResolver$class_object;

#endif	/* _JC_polyglot_types_ClassResolver_H_ */
